#include <QApplication>
#include <QWidget>
#include <QShortcut>
#include <QScreen>
#include <QVBoxLayout>
#include <QResizeEvent>
#include <QStyle>

#include <QDebug>
#include <QSysInfo>

#include <algorithm>
#include <iostream>

// 1.2

static QString title()
{
    return QLatin1String(qVersion()) + QLatin1Char(' ') + QGuiApplication::platformName()
        + QLatin1Char(' ') + QApplication::style()->objectName();
}

class EventFilter : public QObject
{
public:
    using QObject::QObject;

    bool eventFilter(QObject *watched, QEvent *event) override
    {
        static int n= 0;
        switch (event->type()) {
        case QEvent::Move:
        case QEvent::Resize:
            qDebug() << '#' << n++ << watched->metaObject()->className() << watched->objectName() << event;
            break;
        default:
            break;
        }
        return QObject::eventFilter(watched, event);
    }
};

int main(int argc, char *argv[])
{
    QStringList args;
    std::copy(argv + 1, argv + argc, std::back_inserter(args));

    QApplication app(argc, argv);
    const bool avail = args.contains("-a");
    if (args.contains("-e"))
        app.installEventFilter(new EventFilter(&app));

    QWidget w;
    w.setObjectName("top");
    auto *s = w.screen();

    auto min = avail ? s->availableGeometry().size()
                     : s->geometry().size();

    w.setMinimumSize(min);
    auto size = (QSizeF(min) * 1.5).toSize();
    w.resize(size);

    QString t = title();
    qDebug().noquote() << t << args << '\n' << s->name() << "screen"
                       << s->geometry().size() << "min=" <<min << "size=" << size;
    w.setWindowTitle(t);
    new QShortcut(Qt::CTRL | Qt::Key_Q, &w, SLOT(close()));
    w.show();
    return QCoreApplication::exec();
}
